@@ -54,6 +54,7 @@ def compute():
 def repair():
     '''CLI utilities to repair cut planes'''
 
+
 # pylint: disable=function-redefined
 @repair.command(short_help='Repair one morphology')
 @click.argument('input_file', type=click.Path(exists=True, file_okay=True))
@@ -211,10 +212,11 @@ def file(input_file, output_file):
 @sanitize.command(short_help='Sanitize all morphologies in a folder')
 @click.argument('input_folder')
 @click.argument('output_folder')
-def folder(input_folder, output_folder):
+@click.option('--nprocesses', default=1, help='The number of processes to spawn')
+def folder(input_folder, output_folder, nprocesses):
     '''Sanitize all morphologies in the folder.'''
     from neuror.sanitize import sanitize_all
-    sanitize_all(input_folder, output_folder)
+    sanitize_all(input_folder, output_folder, nprocesses=nprocesses)
 
 
 @cut_plane.group()
@@ -348,16 +350,15 @@ def folder(input_dir, output_dir, width, display, plane):
     '''Compute cut planes for all morphology in INPUT_DIR and save them into OUTPUT_DIR
 
     See "cut-plane compute --help" for more information'''
-    for f in iter_morphology_files(input_dir):
-        L.info('Seaching cut plane for file: %s', f)
-        inputfilename = os.path.join(input_dir, f)
-        outfilename = os.path.join(output_dir, os.path.basename(f) + '.json')
+    for inputfilename in iter_morphology_files(input_dir):
+        L.info('Seaching cut plane for file: %s', inputfilename)
+        outfilename = os.path.join(output_dir, inputfilename.with_suffix('.json'))
         try:
             _export_cut_plane(inputfilename, outfilename, width, display=display,
                               searched_axes=(plane or ('X', 'Y', 'Z')),
                               fix_position=None)
         except Exception as e:  # noqa, pylint: disable=broad-except
-            L.warning('Cut plane computation for %s failed', f)
+            L.warning('Cut plane computation for %s failed', inputfilename)
             L.warning(e, exc_info=True)
 
 
